hepstats.hypotests.calculators.frequentist\_calculator module
=============================================================

.. automodule:: hepstats.hypotests.calculators.frequentist_calculator
   :members:
   :undoc-members:
   :show-inheritance:
   :inherited-members:
